<!--
  选择添加参会人员弹框 添加成员后与调度弹框及PTT弹框的逻辑联动都放在状态管理中处理src/store/modules/ptt.js
 -->
<template>
  <el-dialog
    title="添加成员"
    v-bind="$attrs"
    width="507px"
    :modal="false"
    :close-on-click-modal="false"
    :close-on-press-escape="false"
    v-dialog-drag
    @open="onOpenAddUsers"
    @close="onClose"
  >
    <div class="list scroll">
      <div v-for="(item, index) in unParticipated" :key="item.dispatchNo" class="item scroll-item" @click="select(index, item)">
        <div class="scroll-photo">
          <div class="scroll-photo-name">{{ item.dispatchNo }}</div>
          <div class="scroll-photo-checkbox">
            <div class="no-select" v-if="!item.checked"></div>
            <img src="@/assets/images/mapSearch/勾选.png" alt="" class="gx" v-if="item.checked" />
          </div>
        </div>
        <div class="scroll-detail">
          <div>
            <div class="detail-item">{{ item.dispatchNo }}({{ item.statusText }})</div>
            <div class="detail-item">
              <div class="label">所属公司:</div>
              <div class="value">{{ item.organizationName }}</div>
            </div>
            <div class="detail-item">
              <div class="label">所属驻勤点:</div>
              <div class="value">{{ item.securityStationName }}</div>
            </div>
            <div class="detail-item">
              <div class="label">设备类型:</div>
              <div class="value">{{ item.deviceType }}</div>
            </div>
            <div class="detail-item">
              <div class="label">设备型号:</div>
              <div class="value">{{ item.deviceModel }}</div>
            </div>
          </div>
        </div>
      </div>
    </div>
    <div class="footer" slot="footer">
      <el-button @click="cancelAddUser">取消</el-button>
      <el-button type="primary" @click="addUsers">确定</el-button>
    </div>
  </el-dialog>
</template>

<script>
import { mapActions, mapMutations, mapState } from "vuex";

export default {
  name: "unParticipatedList",
  components: {},
  props: {
    show: Boolean,
  },
  data() {
    return {};
  },
  computed: {
    ...mapState({
      unParticipated: (state) => state.gwsd.unParticipated,
    }),
  },
  watch: {},
  methods: {
    ...mapActions(["getUnParticipated" /*获取在调度范围内但是未参会的人员*/, "addPTTGroupUsers" /*添加组群成员*/]),
    ...mapMutations([
      "UPDATE_UN_PARTICIPATED" /*更新在调度范围内但是未参会的人员信息*/,
      "UNCHECK_ALL_UN_PARTICIPANT" /*反选所有在调度范围内但是未参会的人员*/,
    ]),
    // 打开弹框回调
    onOpenAddUsers() {
      // 获取在调度范围内但是未参会的人员
      this.getUnParticipated();
    },
    // 关闭弹框回调
    onClose() {
      this.cancelAddUser();
    },
    // 取消
    cancelAddUser() {
      // 反选所有在调度范围内但是未参会的人员，重置列表状态
      this.UNCHECK_ALL_UN_PARTICIPANT();
      this.$emit("close");
      this.$emit("update:visible", false);
    },
    // 确认添加成员
    addUsers() {
      const unParticipated = this.unParticipated.filter((item) => item.checked);
      const payload = unParticipated.map((item) => item.dispatchNo);
      this.addPTTGroupUsers(payload).then((res) => {
        console.log(res);
        // this.calcCurrentPage();
        this.getUnParticipated();
        this.$emit("addUsers");
      });
      this.cancelAddUser();
    },
    /**
     * 勾选成员
     * @param index 下标
     * @param member 成员信息
     */
    select(index, member) {
      // 更新在调度范围内但是未参会的人员信息
      this.UPDATE_UN_PARTICIPATED({
        index,
        member: {
          ...member,
          checked: !member.checked,
        },
      });
    },
  },
  created() {},
  mounted() {},
};
</script>

<style scoped lang="scss">
.scroll {
  height: 535px;
  overflow-y: auto;
  overflow-x: hidden;

  .scroll-item {
    width: 100%;
    height: 173px;
    cursor: pointer;
    border-bottom: 1px solid #bdcfde;
    display: flex;
    align-items: center;
    justify-content: space-between;

    .scroll-photo {
      margin: 0 auto;
      flex: 1;

      &-name {
        width: 70px;
        height: 70px;
        background: #0e71ff;
        border-radius: 50%;
        display: flex;
        align-items: center;
        justify-content: center;
        font-size: 14px;
        color: #fff;
        margin: 0 auto;
      }

      &-checkbox {
        width: 16px;
        height: 16px;
        margin: 12px auto;

        .gx {
          width: 16px;
          height: 16px;
        }

        .no-select {
          width: 16px;
          height: 16px;
          border: 1px solid #000000;
          border-radius: 4px;
        }

        //修改选择框的颜色
        ::v-deep .el-checkbox__input.is-checked .el-checkbox__inner,
        ::v-deep .el-checkbox__input.is-indeterminate .el-checkbox__inner {
          border-color: #1677ff !important;
          background-color: #1677ff !important;
        }

        ::v-deep .el-checkbox__input.is-focus .el-checkbox__inner {
          border-color: #1677ff !important;
        }

        //修改选中后文本的颜色
        ::v-deep .el-checkbox__input.is-checked + .el-checkbox__label {
          color: #1677ff !important;
        }
      }
    }

    .scroll-detail {
      // width: 246px;
      flex: 2;
      display: flex;
      align-items: center;
      justify-content: space-between;

      .detail-box {
        //width: 196px
      }

      .detail-item {
        display: flex;
        align-items: center;
        margin-left: 14px;
        margin-bottom: 8px;
        color: #000000;
        font-size: 12px;

        .label {
          //width: 100px;
          color: rgba(0, 0, 0, 0.65);
        }

        .value {
          //width: 185px;
          display: flex;
          align-items: center;
          overflow: hidden;
          white-space: nowrap;
          text-overflow: ellipsis;

          img {
            width: 16px;
            height: 16px;
            margin-left: 8px;
          }
        }
      }

      .gx {
        width: 16px;
        height: 16px;
      }

      .no-select {
        width: 16px;
        height: 16px;
        border: 1px solid #000000;
        border-radius: 4px;
      }
    }

    &-SignOut,
    &-Offline {
      .scroll-detail {
        .detail-item {
          cursor: not-allowed;

          .label {
            //width: 100px;
            color: #d9d9d9;
          }

          color: #d9d9d9;
        }

        .no-select {
          width: 16px;
          height: 16px;
          background: #e6e6e6;
          border: 1px solid #d9d9d9;
        }
      }
    }

    &-None {
      .scroll-detail {
        .detail-item {
          cursor: not-allowed;

          .label {
            //width: 100px;
            color: #d9d9d9;
          }

          color: #d9d9d9;
        }

        .no-select {
          width: 16px;
          height: 16px;
          background: #e6e6e6;
          border: 1px solid #d9d9d9;
        }
      }
    }
  }
}
</style>
